@@ -22,6 +22,7 @@ from pyxllib.algo.pupil import natural_sort
 from pyxllib.text.pupil import strfind
 from pyxllib.debug.pupil import dprint
 from pyxllib.file.specialist import get_etag, PathBase, File
+from pyxllib.prog.newbie import first_nonnone
 
 ____dir = """
 支持文件或文件夹的对比复制删除等操作的函数：filescmp、filesdel、filescopy
@@ -47,7 +48,7 @@ class Dir(PathBase):
 
     # 一、基本目录类功能
 
-    def __init__(self, path=None, root=None, *, subs=None):
+    def __init__(self, path=None, root=None, *, subs=None, check=True):
         """根目录、工作目录
 
         >> Dir()  # 以当前文件夹作为root
@@ -58,21 +59,27 @@ class Dir(PathBase):
         """
 
         self._path = None
+        self.subs = subs or []  # 初始默认没有选中任何文件（夹）
+
         # 1 快速初始化
         if root is None:
             if isinstance(path, Dir):
                 self._path = path._path
+                # 注意用Dir A 初始化 Dir B，并不会把A的subs传递给B
+                return
             elif isinstance(path, pathlib.Path):
                 self._path = path
+
         # 2 普通初始化
         if self._path is None:
             self._path = self.abspath(path, root)
-        if not self._path:
-            raise ValueError(f'无效路径 {self._path}')
-        elif self._path.is_file():
-            raise ValueError(f'不能用文件初始化一个Dir对象 {self._path}')
 
-        self.subs = subs or []  # 初始默认没有选中任何文件（夹）
+        # 3 检查
+        if check:
+            if not self._path:
+                raise ValueError(f'无效路径 {self._path}')
+            elif self._path.is_file():
+                raise ValueError(f'不能用文件初始化一个Dir对象 {self._path}')
 
     @classmethod
     def safe_init(cls, path, root=None, *, subs=None):
@@ -182,11 +189,28 @@ class Dir(PathBase):
         """ 返回所有subs的File对象 （过滤掉文件对象） """
         return list(map(Dir, filter(lambda p: not p.is_file(), self.subpaths())))
 
-    def select(self, patter, nsort=True, **kwargs):
+    def select(self, patter, nsort=True, type_=None,
+               ignore_backup=False, ignore_special=False,
+               min_size=None, max_size=None,
+               min_ctime=None, max_ctime=None, min_mtime=None, max_mtime=None,
+               **kwargs):
         r""" 增加选中文件，从filesmatch衍生而来，参数含义见 filesfilter
 
-        :param nsort: 是否使用自然排序，关闭可以加速
+        :param bool nsort: 是否使用自然排序，关闭可以加速
+        :param str type_:
+            None，所有文件
+            'file'，只匹配文件
+            'dir', 只匹配目录
+        :param bool ignore_backup: 如果设为False，会过滤掉自定义的备份文件格式，不获取备份类文件
+        :param bool ignore_special: 自动过滤掉 '.git'、'$RECYCLE.BIN' 目录下文件
+        :param int min_size: 文件大小过滤，单位Byte
+        :param int max_size: ~
+        :param str min_ctime: 创建时间的过滤，格式'2019-09-01'或'2019-09-01 00:00'
+        :param str max_ctime: ~
+        :param str min_mtime: 修改时间的过滤
+        :param str max_mtime: ~
         :param kwargs: see filesfilter
+        :seealso: filesfilter
 
         注意select和exclude的增减操作是不断叠加的，而不是每次重置！
         如果需要重置，应该重新定义一个Folder类
@@ -201,11 +225,58 @@ class Dir(PathBase):
 
         >> Dir(r'C:/pycode/code4101py').select('*.py', min_mtime=Datetime(2020, 3, 1))  # 修改时间在3月1日以上的
         """
-        subs = filesmatch(patter, root=str(self), **kwargs)
+        subs = filesmatch(patter, root=str(self), type_=type_,
+                          ignore_backup=ignore_backup, ignore_special=ignore_special,
+                          min_size=min_size, max_size=max_size,
+                          min_ctime=min_ctime, max_ctime=max_ctime, min_mtime=min_mtime, max_mtime=max_mtime,
+                          **kwargs)
         subs = self.subs + subs
         if nsort: subs = natural_sort(subs)
         return Dir(self._path, subs=subs)
 
+    def select_files(self, patter, nsort=True,
+                     ignore_backup=False, ignore_special=False,
+                     min_size=None, max_size=None,
+                     min_ctime=None, max_ctime=None, min_mtime=None, max_mtime=None):
+        """ TODO 这系列的功能可以优化加速，在没有复杂规则的情况下，可以尽量用源生的py检索方式实现 """
+        subs = filesmatch(patter, root=str(self), type_='file',
+                          ignore_backup=ignore_backup, ignore_special=ignore_special,
+                          min_size=min_size, max_size=max_size,
+                          min_ctime=min_ctime, max_ctime=max_ctime,
+                          min_mtime=min_mtime, max_mtime=max_mtime)
+        if nsort:
+            subs = natural_sort(subs)
+        for x in subs:
+            yield File(self._path / x, check=False)
+
+    def select_dirs(self, patter, nsort=True,
+                    ignore_backup=False, ignore_special=False,
+                    min_size=None, max_size=None,
+                    min_ctime=None, max_ctime=None, min_mtime=None, max_mtime=None):
+        subs = filesmatch(patter, root=str(self), type_='dir',
+                          ignore_backup=ignore_backup, ignore_special=ignore_special,
+                          min_size=min_size, max_size=max_size,
+                          min_ctime=min_ctime, max_ctime=max_ctime,
+                          min_mtime=min_mtime, max_mtime=max_mtime)
+        if nsort:
+            subs = natural_sort(subs)
+        for x in subs:
+            yield Dir(self._path / x, check=False)
+
+    def select_paths(self, patter, nsort=True,
+                     ignore_backup=False, ignore_special=False,
+                     min_size=None, max_size=None,
+                     min_ctime=None, max_ctime=None, min_mtime=None, max_mtime=None):
+        subs = filesmatch(patter, root=str(self),
+                          ignore_backup=ignore_backup, ignore_special=ignore_special,
+                          min_size=min_size, max_size=max_size,
+                          min_ctime=min_ctime, max_ctime=max_ctime,
+                          min_mtime=min_mtime, max_mtime=max_mtime)
+        if nsort:
+            subs = natural_sort(subs)
+        for x in subs:
+            yield self._path / x
+
     def procpaths(self, func, start=None, end=None, ref_dir=None, pinterval=None, max_workers=1, interrupt=True):
         """ 对选中的文件迭代处理
 
@@ -338,7 +409,8 @@ def filescmp(f1, f2, shallow=True):
 def filesfilter(files, *, root=os.curdir, type_=None,
                 ignore_backup=False, ignore_special=False,
                 min_size=None, max_size=None,
-                min_ctime=None, max_ctime=None, min_mtime=None, max_mtime=None):
+                min_ctime=None, max_ctime=None,
+                min_mtime=None, max_mtime=None):
     """
     :param files: 类list对象
     :param type_:
@@ -364,21 +436,24 @@ def filesfilter(files, *, root=os.curdir, type_=None,
         elif type_ == 'dir' and not os.path.isdir(f):
             return False
 
-        msg = os.stat(f)
-        if min_size is not None or max_size is not None:
-            size = File(f).size
-            if min_size is not None and size < min_size: return False
-            if max_size is not None and size > max_size: return False
+        # 尽量避免调用 os.stat，判断是否有自定义大小、时间规则，没有可以跳过这部分
+        check_arg = first_nonnone([min_size, max_size, min_ctime, max_ctime, min_mtime, max_mtime])
+        if check_arg is not None:
+            msg = os.stat(f)
+            if first_nonnone([min_size, max_size]) is not None:
+                size = File(f).size
+                if min_size is not None and size < min_size: return False
+                if max_size is not None and size > max_size: return False
 
-        if min_ctime or max_ctime:
-            file_ctime = msg.st_ctime
-            if min_ctime and Datetime(file_ctime) < min_ctime: return False
-            if max_ctime and Datetime(file_ctime) > max_ctime: return False
+            if min_ctime or max_ctime:
+                file_ctime = msg.st_ctime
+                if min_ctime and Datetime(file_ctime) < min_ctime: return False
+                if max_ctime and Datetime(file_ctime) > max_ctime: return False
 
-        if min_mtime or max_mtime:
-            file_mtime = msg.st_mtime
-            if min_mtime and Datetime(file_mtime) < min_mtime: return False
-            if max_mtime and Datetime(file_mtime) > max_mtime: return False
+            if min_mtime or max_mtime:
+                file_mtime = msg.st_mtime
+                if min_mtime and Datetime(file_mtime) < min_mtime: return False
+                if max_mtime and Datetime(file_mtime) > max_mtime: return False
 
         if ignore_special:
             parts = File(f).parts
@@ -595,7 +670,7 @@ def filescopy(src, dst, *, if_exists=None, treeroot=None, **kwargs):
         对src中匹配到的所有文件，都会去掉treeroot的父目录前缀
             然后将剩下文件的所有相对路径结构，拷贝到dst目录下
         示例：将a目录下所有png图片原结构拷贝到b目录下
-            filescopy('a/**/*.png', 'b/', if_exists='delete', treeroot='a')
+            filescopy('a/**/*.png', 'b/', if_exists='replace', treeroot='a')
         友情提示：treeroot要跟src使用同样的相对或绝对路径值，否则可能出现意外错误
 
         >> filescopy('filesmatch/**/*.png', 'filesmatch+/', treeroot='filesmatch')
@@ -613,7 +688,7 @@ def filescopy(src, dst, *, if_exists=None, treeroot=None, **kwargs):
 def filesmove(src, dst, *, if_exists=None, treeroot=None, **kwargs):
     r"""与filescopy高度相同，见filescopy文档
 
-    >> filesmove('a.xslx', 'A.xlsx', if_exists='delete')  # 等价于 os.rename('a.xlsx', 'A.xlsx')
+    >> filesmove('a.xslx', 'A.xlsx', if_exists='replace')  # 等价于 os.rename('a.xlsx', 'A.xlsx')
     """
     return _files_copy_move_base(src, dst, shutil.move, shutil.move,
                                  if_exists=if_exists, treeroot=treeroot, **kwargs)
@@ -668,7 +743,7 @@ def merge_dir(src, dst, if_exists='skip'):
     Dir(src).select('**/*', type_='dir', max_size=0).select('**/*', type_='file').procpaths(func, ref_dir=dst)
 
 
-def extract_files(src, dst, pattern, if_exists='delete'):
+def extract_files(src, dst, pattern, if_exists='replace'):
     """ 提取满足pattern模式的文件
     """
     d1, d2 = Dir(src), Dir(dst)
